@@ -102,6 +102,16 @@ class cached_property(object):
         setattr(obj, self.func.__name__, value)
         return value
 
+    @classmethod
+    def bust_caches(cls, obj):
+        for name, _ in cls.get_cached_properties(obj):
+            if name in obj.__dict__:
+                delattr(obj, name)
+
+    @classmethod
+    def get_cached_properties(cls, obj):
+        return inspect.getmembers(type(obj), lambda x: isinstance(x, cls))
+
 
 def _compose2(f, g):
     return lambda *args, **kwargs: f(g(*args, **kwargs))
@@ -125,21 +135,6 @@ def make_single_arity(function):
     return wrapped
 
 
-def kwargs_make_single_arity(function):
-    @functools.wraps(function)
-    def wrapped(kwargs):
-        return function(**kwargs)
-    return wrapped
-
-
-def args_kwargs_make_single_arity(function):
-    @functools.wraps(function)
-    def wrapped(val):
-        (args, kwargs) = val
-        return function(*args, **kwargs)
-    return wrapped
-
-
 def force_args_return(function):
     @functools.wraps(function)
     def wrapped(*args, **kwargs):
