@@ -1,3 +1,4 @@
+import pytest
 from lxml import etree
 
 from okcupyd import xpath
@@ -16,3 +17,12 @@ def test_selected_attribute():
 
     assert xpath.xpb.element.select_attribute_('value', elem=tree) == ['1', '2']
 
+
+def test_text_for_many():
+    tree = etree.XML("<top><container>"
+                     "<element value='1'>one</element>"
+                     "<element value='2'>two</element>"
+                     "</container></top>")
+
+    result = xpath.xpb.container.element.text_.apply_(tree)
+    assert set(result) == set(['one', 'two'])
